Object-Oriented Programming
:::::::::::::::::::::::::::

.. toctree::
    :maxdepth: 3

    managinglargerprograms.rst
    gettingstarted.rst
    usingobjects.rst
    startingwithprograms.rst
    subdividingaprogram.rst
    ourfirstpythonobject.rst
    classesastype.rst
    objectlifecycle.rst
    multipleinstances.rst
    inheritance.rst
    summary.rst
    glossary.rst
    Exercises.rst
    mixedupcode.rst
    writecode.rst
    group-classes.rst
    group-mult-classes.rst
